import os
import pytest
import requests
from tenacity import retry, stop_after_attempt, wait_fixed

@pytest.mark.integration_only
def test_health_check():
    """
    Calls health check endpoint
    """
    test_health_check()


@retry(stop=stop_after_attempt(2), wait=wait_fixed(1))
def test_health_check():
    """
    Testing Health Check endpoint service
    :return: None
    """
    svc_health_check_url = os.getenv('SVC_HEALTH_CHECK_URL')
    print(f"URL = {svc_health_check_url}")
    headers = {
        "Accept": "application/json"
    }
    response = requests.get(svc_health_check_url, headers=headers)
    assert response.ok, f'Expected health_check call to succeed. {response.text}'
    response_json = response.json()
    expected_message = 'UP'
    assert expected_message in response_json.get('status'), f'Expected {expected_message} in message. Actual: {response.json()}'
